@@ -4,12 +4,13 @@ from subprocess import Popen, PIPE
 
 from django.conf import settings
 from django.contrib.staticfiles.finders import find
+from django.utils.encoding import smart_text
 
-from assetfiles.filters.base import BaseFilter, ExtFilter
+from assetfiles.filters import BaseFilter, ExtensionMixin
 import assetfiles.settings
 
 
-class SassFilter(ExtFilter, BaseFilter):
+class SassFilter(ExtensionMixin, BaseFilter):
     """
     Filters Sass files into CSS.
 
@@ -22,7 +23,8 @@ class SassFilter(ExtFilter, BaseFilter):
     functions_path = os.path.abspath(
         os.path.join(os.path.dirname(__file__), '../scripts/sass_functions.rb'))
 
-    def __init__(self, options=None):
+    def __init__(self, options=None, *args, **kwargs):
+        super(SassFilter, self).__init__(*args, **kwargs)
         if options is None:
             options = {}
         if 'compass' not in options:
@@ -38,19 +40,19 @@ class SassFilter(ExtFilter, BaseFilter):
         env.update({'DJANGO_STATIC_URL': settings.STATIC_URL})
 
         process = Popen(command, shell=True, stdout=PIPE, stderr=PIPE, env=env)
-        stdout, stderr = process.communicate()
+        stdout, stderr = [smart_text(s) for s in process.communicate()]
 
         if process.returncode:
             raise SassFilterError(stderr)
         else:
             return stdout
 
-    def skip_output_path(self, output_path):
+    def is_filterable(self, output_path):
         """
         Skips files prefixed with a '_'. These are Sass dependencies.
         """
         _, file_name = os.path.split(output_path)
-        return file_name.startswith('_')
+        return not file_name.startswith('_')
 
     def _build_args(self):
         """
