@@ -7,11 +7,23 @@ from django.contrib.staticfiles import finders, storage
 from django.test import TestCase
 from django.utils.functional import empty
 
-from assetfiles import filters
-from assetfiles.filters.base import BaseFilter, ExtFilter
+from assetfiles import assets, filters
 import assetfiles.settings
 
 
+def filter(path):
+    asset_path, filter = assets.find(path)
+    return filter.filter(asset_path).strip()
+
+
+def is_glob2_available():
+    try:
+        import glob2
+        return True
+    except ImportError:
+        return False
+
+
 class AssetfilesTestCase(TestCase):
     def setUp(self):
         # Clear the cached staticfiles_storage out, this is because when it first
@@ -43,26 +55,3 @@ class AssetfilesTestCase(TestCase):
             if content: file.write(content)
 
         return abspath
-
-
-class ReplaceFilter(ExtFilter, BaseFilter):
-    input_exts = ('foo', 'baz')
-    output_ext = 'bar'
-
-    def __init__(self, pattern='a', replacement='b'):
-        self.pattern = pattern
-        self.replacement = replacement
-
-    def filter(self, input):
-        with open(input, 'r') as file:
-            return file.read().replace(self.pattern, self.replacement)
-
-
-class Filter1(ExtFilter, BaseFilter):
-    input_exts = ('in', 'in1')
-    output_ext = 'out'
-
-
-class Filter2(ExtFilter, BaseFilter):
-    input_ext = 'in2'
-    output_ext = 'out2'
