@@ -34,6 +34,7 @@ STATIC_URL = '/static/'
 
 STATICFILES_DIRS = (
     path.join(PROJECT_ROOT, 'static'),
+    ('prefix', path.join(PROJECT_ROOT, 'static-prefix'))
 )
 
 STATICFILES_FINDERS = (
@@ -44,3 +45,6 @@ STATICFILES_FINDERS = (
 TEMPLATE_DIRS = (
     path.join(PROJECT_ROOT, 'templates'),
 )
+
+SECRET_KEY = 'ev2pj15ucf^d84l216^@-mv)pl4$^@9g4)9_)7xi@0j0xop94f'
+DEFAULT_CHARSET = 'utf-8'
